@@ -1,5 +1,5 @@
 #!/bin/sh
-# Copyright 2005-2019 ECMWF.
+# (C) Copyright 2005- ECMWF.
 #
 # This software is licensed under the terms of the Apache Licence Version 2.0
 # which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -9,17 +9,6 @@
 
 . ./include.sh
 
-if [ ! -f "${data_dir}/multi.grib2" ] 
-then
-  echo "SKIP test 1: $0"
-else
-  ${examples_dir}/c_grib_multi > /dev/null
-fi
-
-if [ ! -f "${data_dir}/multi_created.grib2" ]
-then
-  echo "SKIP test 2: $0"
-else
-  ${examples_dir}/c_multi2 > /dev/null
-fi
-
+# Test decoding multi-field GRIB2 data
+${examples_dir}/c_grib_multi
+${examples_dir}/c_multi2
