@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2019 ECMWF.
+ * (C) Copyright 2005- ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -25,44 +25,44 @@
 
 #include "eccodes.h"
 
-void usage(const char* prog) {
-    printf("usage: %s filename\n",prog);
+void usage(const char* prog)
+{
+    printf("usage: %s filename\n", prog);
     exit(1);
 }
 
 int main(int argc, char** argv)
 {
-    int err = 0,i;
-    double *values = NULL;
-    double max,min,average;
-    size_t values_len= 0;
+    int err        = 0, i;
+    double* values = NULL;
+    double max, min, average;
+    size_t values_len = 0;
 
     FILE* in = NULL;
-    char* filename ;
-    codes_handle *h = NULL;
+    char* filename;
+    codes_handle* h = NULL;
 
-    if (argc<2) usage(argv[0]);
-    filename=argv[1];
+    if (argc < 2) usage(argv[0]);
+    filename = argv[1];
 
-    in = fopen(filename,"rb");
-    if(!in) {
-        printf("ERROR: unable to open file %s\n",filename);
+    in = fopen(filename, "rb");
+    if (!in) {
+        fprintf(stderr, "ERROR: unable to open file %s\n", filename);
         return 1;
     }
 
     /* create new handle from a message in a file*/
-    while((h = codes_handle_new_from_file(0,in,&err)) != NULL) {
-
+    while ((h = codes_handle_new_from_file(0, in, &err)) != NULL) {
         /* get the size of the values array*/
-        CODES_CHECK(codes_get_size(h,"values",&values_len),0);
+        CODES_CHECK(codes_get_size(h, "values", &values_len), 0);
 
-        values = malloc(values_len*sizeof(double));
+        values = malloc(values_len * sizeof(double));
 
         /* get data values*/
-        CODES_CHECK(codes_get_double_array(h,"values",values,&values_len),0);
+        CODES_CHECK(codes_get_double_array(h, "values", values, &values_len), 0);
 
-        for(i = 0; i < values_len; i++)
-            printf("%d  %.10e\n",i+1,values[i]);
+        for (i = 0; i < values_len; i++)
+            printf("%d  %.10e\n", i + 1, values[i]);
 
         free(values);
 
