@@ -1,5 +1,5 @@
 #!/bin/sh
-# Copyright 2005-2019 ECMWF.
+# (C) Copyright 2005- ECMWF.
 #
 # This software is licensed under the terms of the Apache Licence Version 2.0
 # which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -12,10 +12,14 @@
 
 label="get_product_kind_f"
 fTmp=${label}.tmp
+fOut=${label}.out
 
 # Create a file containing both GRIB and BUFR messages
 cat ${data_dir}/sample.grib2 ${data_dir}/bufr/syno_multi.bufr >$fTmp
 
-${examples_dir}/eccodes_f_get_product_kind $fTmp >/dev/null 2>&1
+${examples_dir}/eccodes_f_get_product_kind $fTmp > $fOut
+cat $fOut
+grep -q "product: BUFR" $fOut
+grep -q "product: GRIB" $fOut
 
-rm -f ${fTmp}
+rm -f $fTmp $fOut
