@@ -3,11 +3,11 @@
 . ./include.sh
 
 INPUT=${data_dir}/tigge_pf_ecmwf.grib2
-OUTPUT=out.grib
+OUTPUT=temp.binary_message.grib
 
 $PYTHON $examples_src/binary_message.py $INPUT $OUTPUT
 ${tools_dir}/grib_compare $INPUT $OUTPUT
-rm $OUTPUT || true
+rm -f $OUTPUT
 
 # GRIB-568 corrupt grib
 # We are expecting the command to fail so must turn off "set -e"
@@ -18,5 +18,4 @@ status=$?
 set -e
 # Check command did indeed fail
 [ $status != 0 ]
-rm $OUTPUT || true
-
+rm -f $OUTPUT
