@@ -345,7 +345,7 @@ static int grib_concept_apply(grib_accessor* a, const char* name)
     grib_action* act             = a->creator;
     int nofail                   = action_concept_get_nofail(a);
 
-    Assert(concepts != NULL);
+    DebugAssert(concepts);
 
     c = (grib_concept_value*)grib_trie_get(concepts->index, name);
 
@@ -357,9 +357,7 @@ static int grib_concept_apply(grib_accessor* a, const char* name)
         if (err) {
             size_t i = 0, concept_count = 0;
             long dummy = 0, editionNumber = 0;
-            char* all_concept_vals[MAX_NUM_CONCEPT_VALUES] = {
-                NULL,
-            }; /* sorted array containing concept values */
+            char* all_concept_vals[MAX_NUM_CONCEPT_VALUES] = {NULL,}; /* sorted array containing concept values */
             grib_concept_value* pCon = concepts;
 
             grib_context_log(h->context, GRIB_LOG_ERROR, "concept: no match for %s=%s", act->name, name);
@@ -367,6 +365,10 @@ static int grib_concept_apply(grib_accessor* a, const char* name)
                 grib_context_log(h->context, GRIB_LOG_ERROR,
                                  "Please check the Parameter Database 'https://apps.ecmwf.int/codes/grib/param-db/?id=%s'", name);
             }
+            if (strcmp(act->name, "shortName") == 0) {
+                grib_context_log(h->context, GRIB_LOG_ERROR,
+                                 "Please check the Parameter Database 'https://apps.ecmwf.int/codes/grib/param-db/'");
+            }
             if (grib_get_long(h, "edition", &editionNumber) == GRIB_SUCCESS) {
                 grib_context_log(h->context, GRIB_LOG_ERROR, "concept: input handle edition=%ld", editionNumber);
             }
@@ -630,7 +632,7 @@ static int unpack_string(grib_accessor* a, char* val, size_t* len)
         *len = slen;
         return GRIB_BUFFER_TOO_SMALL;
     }
-    strncpy(val, p, slen);
+    strcpy(val, p); /* NOLINT: CWE-119 clang-analyzer-security.insecureAPI.strcpy */
     *len = slen;
 #if 0
     if (a->context->debug==1) {
