@@ -55,7 +55,7 @@ grib_iarray* grib_iarray_new(grib_context* c, size_t size, size_t incsize)
     v = (grib_iarray*)grib_context_malloc(c, sizeof(grib_iarray));
     if (!v) {
         grib_context_log(c, GRIB_LOG_ERROR,
-                         "grib_iarray_new unable to allocate %d bytes\n", sizeof(grib_iarray));
+                         "grib_iarray_new unable to allocate %ld bytes\n", sizeof(grib_iarray));
         return NULL;
     }
     v->context             = c;
@@ -66,7 +66,7 @@ grib_iarray* grib_iarray_new(grib_context* c, size_t size, size_t incsize)
     v->number_of_pop_front = 0;
     if (!v->v) {
         grib_context_log(c, GRIB_LOG_ERROR,
-                         "grib_iarray_new unable to allocate %d bytes\n", sizeof(long) * size);
+                         "grib_iarray_new unable to allocate %ld bytes\n", sizeof(long) * size);
         return NULL;
     }
     return v;
@@ -107,7 +107,7 @@ static grib_iarray* grib_iarray_resize_to(grib_iarray* v, size_t newsize)
     newv = (long*)grib_context_malloc_clear(c, newsize * sizeof(long));
     if (!newv) {
         grib_context_log(c, GRIB_LOG_ERROR,
-                         "grib_iarray_resize unable to allocate %d bytes\n", sizeof(long) * newsize);
+                         "grib_iarray_resize unable to allocate %ld bytes\n", sizeof(long) * newsize);
         return NULL;
     }
 
