@@ -28,6 +28,7 @@
    MEMBERS    = long global
    MEMBERS    = double lon_first
    MEMBERS    = double lon_last
+   MEMBERS    = int legacy
    END_CLASS_DEF
 
  */
@@ -68,6 +69,7 @@ typedef struct grib_nearest_reduced
     long global;
     double lon_first;
     double lon_last;
+    int legacy; /* -1, 0 or 1 */
 } grib_nearest_reduced;
 
 extern grib_nearest_class* grib_nearest_class_gen;
@@ -97,6 +99,7 @@ static int init(grib_nearest* nearest, grib_handle* h, grib_arguments* args)
     self->Nj                   = grib_arguments_get_name(h, args, self->cargs++);
     self->pl                   = grib_arguments_get_name(h, args, self->cargs++);
     self->j                    = (int*)grib_context_malloc(h->context, 2 * sizeof(int));
+    self->legacy               = -1;
     if (!self->j)
         return GRIB_OUT_OF_MEMORY;
     self->k = (int*)grib_context_malloc(nearest->context, 4 * sizeof(int));
@@ -132,7 +135,7 @@ static int is_legacy(grib_handle* h)
     return (grib_get_long(h, "legacyGaussSubarea", &is_legacy) == GRIB_SUCCESS && is_legacy == 1);
 }
 
-#if 1
+/* Old implementation in src/deprecated/grib_nearest_class_reduced.old */
 static int find(grib_nearest* nearest, grib_handle* h,
                 double inlat, double inlon, unsigned long flags,
                 double* outlats, double* outlons, double* values,
@@ -148,9 +151,12 @@ static int find(grib_nearest* nearest, grib_handle* h,
     long iradius;
     double radius;
     int ilat = 0, ilon = 0;
-    const int is_legacy_grib                  = is_legacy(h);
     get_reduced_row_proc get_reduced_row_func = &grib_get_reduced_row;
-    if (is_legacy_grib) {
+
+    if (self->legacy == -1 || (flags & GRIB_NEAREST_SAME_GRID) == 0) {
+        self->legacy = is_legacy(h);
+    }
+    if (self->legacy == 1) {
         get_reduced_row_func = &grib_get_reduced_row_legacy;
     }
 
@@ -167,6 +173,9 @@ static int find(grib_nearest* nearest, grib_handle* h,
         return ret;
     radius = ((double)iradius) / 1000.0;
 
+    /* Compute lat/lon info, create iterator etc if it's the 1st time or different grid.
+     * This is for performance: if the grid has not changed, we only do this once
+     * and reuse for other messages */
     if (!nearest->h || (flags & GRIB_NEAREST_SAME_GRID) == 0) {
         double dummy = 0;
         double olat  = 1.e10;
@@ -209,8 +218,8 @@ static int find(grib_nearest* nearest, grib_handle* h,
             }
             while (lon > 360)
                 lon -= 360;
-            if (!self->global) {     /* ECC-756 */
-                if (!is_legacy_grib) /*TODO*/
+            if (!self->global) {       /* ECC-756 */
+                if (self->legacy == 0) /*TODO*/
                     if (lon > 180 && lon < 360)
                         lon -= 360;
             }
@@ -221,6 +230,9 @@ static int find(grib_nearest* nearest, grib_handle* h,
     }
     nearest->h = h;
 
+    /* Compute distances if it's the 1st time or different point or different grid.
+     * This is for performance: if the grid and the input point have not changed
+     * we only do this once and reuse for other messages */
     if (!self->distances || (flags & GRIB_NEAREST_SAME_POINT) == 0 || (flags & GRIB_NEAREST_SAME_GRID) == 0) {
         double* lons           = NULL;
         int nlon               = 0;
@@ -234,7 +246,7 @@ static int find(grib_nearest* nearest, grib_handle* h,
         }
         else {
             /* TODO: Experimental */
-            if (!is_legacy_grib)
+            if (self->legacy == 0)
                 if (inlon > 180 && inlon < 360)
                     inlon -= 360;
         }
@@ -410,7 +422,7 @@ static int find(grib_nearest* nearest, grib_handle* h,
         for (jj = 0; jj < 2; jj++) {
             for (ii = 0; ii < 2; ii++) {
                 self->distances[kk] = geographic_distance_spherical(radius, inlon, inlat,
-                                                            self->lons[self->k[kk]], self->lats[self->j[jj]]);
+                                                                    self->lons[self->k[kk]], self->lats[self->j[jj]]);
                 kk++;
             }
         }
@@ -434,144 +446,6 @@ static int find(grib_nearest* nearest, grib_handle* h,
 
     return GRIB_SUCCESS;
 }
-#else
-static int find(grib_nearest* nearest, grib_handle* h,
-                double inlat, double inlon, unsigned long flags,
-                double* outlats, double* outlons, double* values,
-                double* distances, double* distances, int* indexes, size_t* len)
-{
-    grib_nearest_reduced* self = (grib_nearest_reduced*)nearest;
-    int ret = 0, kk = 0, ii = 0, jj = 0;
-    double* pl = NULL;
-    int ilat;
-    size_t nvalues = 0;
-    if (!nearest->h || (flags & GRIB_NEAREST_SAME_DATA) == 0 || nearest->h != h) {
-        grib_iterator* iter = NULL;
-        double lat = 0, lon = 0;
-
-        if ((ret = grib_get_size(h, self->values_key, &nvalues)) != GRIB_SUCCESS)
-            return ret;
-        nearest->values_count = nvalues;
-        if (nearest->values)
-            grib_context_free(nearest->context, nearest->values);
-        nearest->values = grib_context_malloc(h->context, nvalues * sizeof(double));
-        if (!nearest->values)
-            return GRIB_OUT_OF_MEMORY;
-
-        ret = grib_get_double_array_internal(h, self->values_key,
-                                             nearest->values, &(nearest->values_count));
-        if (ret != GRIB_SUCCESS)
-            grib_context_log(nearest->context, GRIB_LOG_ERROR,
-                             "nearest: unable to get values array");
-
-        if (!nearest->h || (flags & GRIB_NEAREST_SAME_GRID) == 0) {
-            double dummy = 0;
-            double olat  = 1.e10;
-            ilat = 0, ilon = 0;
-            long n = 0;
-
-            if (grib_is_missing(h, self->Nj, &ret)) {
-                grib_context_log(h->context, GRIB_LOG_DEBUG, "Key '%s' is missing", self->Nj);
-                return ret ? ret : GRIB_GEOCALCULUS_PROBLEM;
-            }
-
-            if ((ret = grib_get_long(h, self->Nj, &n)) != GRIB_SUCCESS)
-                return ret;
-            self->lats_count = n;
-
-            if (self->lats)
-                grib_context_free(nearest->context, self->lats);
-            self->lats = grib_context_malloc(nearest->context,
-                                             self->lats_count * sizeof(double));
-            if (!self->lats)
-                return GRIB_OUT_OF_MEMORY;
-
-            if (self->lons)
-                grib_context_free(nearest->context, self->lons);
-            self->lons = grib_context_malloc(nearest->context,
-                                             nearest->values_count * sizeof(double));
-            if (!self->lons)
-                return GRIB_OUT_OF_MEMORY;
-
-            iter = grib_iterator_new(h, 0, &ret);
-            while (grib_iterator_next(iter, &lat, &lon, &dummy)) {
-                if (olat != lat) {
-                    self->lats[ilat++] = lat;
-                    olat               = lat;
-                }
-                self->lons[ilon++] = lon;
-            }
-            grib_iterator_delete(iter);
-        }
-        nearest->h = h;
-    }
-
-    if (!self->distances || (flags & GRIB_NEAREST_SAME_POINT) == 0 || (flags & GRIB_NEAREST_SAME_GRID) == 0) {
-        double* lons = NULL;
-        int nlon     = 0;
-        int plsize   = 0;
-
-        self->distances = (double*)grib_context_malloc(nearest->context, 4 * sizeof(double));
-        if (!self->distances)
-            return GRIB_OUT_OF_MEMORY;
-
-        grib_binary_search(self->lats, self->lats_count - 1, inlat,
-                           &(self->j[0]), &(self->j[1]));
-
-        plsize = self->lats_count;
-        pl     = (double*)grib_context_malloc(h->context, plsize * sizeof(double));
-        if (!pl)
-            return GRIB_OUT_OF_MEMORY;
-        if ((ret = grib_get_double_array(h, "pl", pl, &plsize)) != GRIB_SUCCESS)
-            return ret;
-
-        nlon = 0;
-        for (jj = 0; jj < self->j[0]; jj++) {
-            nlon += pl[jj];
-        }
-        lons = self->lons + nlon;
-        grib_binary_search(lons, pl[self->j[0]] - 1, inlon,
-                           &(self->k[0]), &(self->k[1]));
-        self->k[0] += nlon;
-        self->k[1] += nlon;
-
-        nlon = 0;
-        for (jj = 0; jj < self->j[1]; jj++) {
-            nlon += pl[jj];
-        }
-        lons = self->lons + nlon;
-        grib_binary_search(lons, pl[self->j[1]] - 1, inlon,
-                           &(self->k[2]), &(self->k[3]));
-        self->k[2] += nlon;
-        self->k[3] += nlon;
-
-        kk = 0;
-        for (ii = 0; ii < 2; ii++) {
-            for (jj = 0; jj < 2; jj++) {
-                self->distances[kk] = geographic_distance_spherical(radius, inlon, inlat,
-                                                            self->lons[self->k[kk]], self->lats[self->j[jj]]);
-                kk++;
-            }
-        }
-
-        grib_context_free(h->context, pl);
-    }
-
-    kk = 0;
-    for (ii = 0; ii < 2; ii++) {
-        for (jj = 0; jj < 2; jj++) {
-            distances[kk] = self->distances[kk];
-            outlats[kk]   = self->lats[self->j[jj]];
-            outlons[kk]   = self->lons[self->k[kk]];
-            values[kk]    = nearest->values[self->k[kk]];
-            indexes[kk]   = self->k[kk];
-            kk++;
-        }
-    }
-
-    return GRIB_SUCCESS;
-}
-#endif
 
 static int destroy(grib_nearest* nearest)
 {
