@@ -358,25 +358,27 @@ static void grib_trie_with_rank_delete_container_list(grib_context* c,grib_trie_
 }
 */
 
+static void _grib_trie_with_rank_delete_container(grib_trie_with_rank* t)
+{
+    int i;
+    DebugAssert(t);
+    for (i = t->first; i <= t->last; i++)
+        if (t->next[i]) {
+            grib_trie_with_rank_delete_container(t->next[i]);
+        }
+    grib_oarray_delete(t->context, t->objs);
+    /* grib_trie_with_rank_delete_container_list(t->context,t->list); */
+#ifdef RECYCLE_TRIE
+    grib_context_free_persistent(t->context, t);
+#else
+    grib_context_free(t->context, t);
+#endif
+}
 void grib_trie_with_rank_delete_container(grib_trie_with_rank* t)
 {
     GRIB_MUTEX_INIT_ONCE(&once, &init);
     GRIB_MUTEX_LOCK(&mutex);
-    DebugAssert(t);
-    {
-        int i;
-        for (i = t->first; i <= t->last; i++)
-            if (t->next[i]) {
-                grib_trie_with_rank_delete_container(t->next[i]);
-            }
-        grib_oarray_delete(t->context, t->objs);
-        /* grib_trie_with_rank_delete_container_list(t->context,t->list); */
-#ifdef RECYCLE_TRIE
-        grib_context_free_persistent(t->context, t);
-#else
-        grib_context_free(t->context, t);
-#endif
-    }
+    _grib_trie_with_rank_delete_container(t);
     GRIB_MUTEX_UNLOCK(&mutex);
 }
 
@@ -452,11 +454,8 @@ int grib_trie_with_rank_insert(grib_trie_with_rank* t, const char* key, void* da
 {
     grib_trie_with_rank* last = t;
     const char* k             = key;
-
-    if (!t) {
-        Assert(!"grib_trie_with_rank_insert: grib_trie==NULL");
-        return -1;
-    }
+    DebugAssert(t);
+    if (!t) return -1;
 
     GRIB_MUTEX_INIT_ONCE(&once, &init);
     GRIB_MUTEX_LOCK(&mutex);
@@ -487,7 +486,7 @@ int grib_trie_with_rank_insert(grib_trie_with_rank* t, const char* key, void* da
     grib_oarray_push(t->context, t->objs, data);
     /* grib_trie_with_rank_insert_in_list(t,data); */
     GRIB_MUTEX_UNLOCK(&mutex);
-    return grib_oarray_used_size(t->objs);
+    return t->objs->n; /* grib_oarray_used_size(t->objs) */
 }
 
 /*
