@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2019 ECMWF.
+ * (C) Copyright 2005- ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -41,8 +41,7 @@
 
 
 #ifdef __AVX__
-static
-void avx_minmax_val(const double *restrict buf, long nframes, double *min, double *max)
+static void avx_minmax_val(const double* restrict buf, long nframes, double* min, double* max)
 {
     __m256d current_max, current_min, work;
 
@@ -51,10 +50,9 @@ void avx_minmax_val(const double *restrict buf, long nframes, double *min, doubl
     current_max = _mm256_set1_pd(*max);
 
     /* Work input until "buf" reaches 32 byte alignment */
-    while ( ((unsigned long)buf) % 32 != 0 && nframes > 0) {
-
+    while (((unsigned long)buf) % 32 != 0 && nframes > 0) {
         /* Load the next double into the work buffer */
-        work = _mm256_set1_pd(*buf);
+        work        = _mm256_set1_pd(*buf);
         current_min = _mm256_min_pd(current_min, work);
         current_max = _mm256_max_pd(current_max, work);
         buf++;
@@ -63,24 +61,24 @@ void avx_minmax_val(const double *restrict buf, long nframes, double *min, doubl
 
     while (nframes >= 16) {
         /* use 64 byte prefetch? */
-        __builtin_prefetch(buf+64,0,0); /* for GCC 4.3.2+ */
+        __builtin_prefetch(buf + 64, 0, 0); /* for GCC 4.3.2+ */
 
-        work = _mm256_load_pd(buf);
+        work        = _mm256_load_pd(buf);
         current_min = _mm256_min_pd(current_min, work);
         current_max = _mm256_max_pd(current_max, work);
         buf += 4;
-        __builtin_prefetch(buf+64,0,0); /* for GCC 4.3.2+ */
-        work = _mm256_load_pd(buf);
+        __builtin_prefetch(buf + 64, 0, 0); /* for GCC 4.3.2+ */
+        work        = _mm256_load_pd(buf);
         current_min = _mm256_min_pd(current_min, work);
         current_max = _mm256_max_pd(current_max, work);
         buf += 4;
-        __builtin_prefetch(buf+64,0,0); /* for GCC 4.3.2+ */
-        work = _mm256_load_pd(buf);
+        __builtin_prefetch(buf + 64, 0, 0); /* for GCC 4.3.2+ */
+        work        = _mm256_load_pd(buf);
         current_min = _mm256_min_pd(current_min, work);
         current_max = _mm256_max_pd(current_max, work);
         buf += 4;
-        __builtin_prefetch(buf+64,0,0); /* for GCC 4.3.2+ */
-        work = _mm256_load_pd(buf);
+        __builtin_prefetch(buf + 64, 0, 0); /* for GCC 4.3.2+ */
+        work        = _mm256_load_pd(buf);
         current_min = _mm256_min_pd(current_min, work);
         current_max = _mm256_max_pd(current_max, work);
         buf += 4;
@@ -89,7 +87,7 @@ void avx_minmax_val(const double *restrict buf, long nframes, double *min, doubl
 
     /* work through aligned buffers */
     while (nframes >= 4) {
-        work = _mm256_load_pd(buf);
+        work        = _mm256_load_pd(buf);
         current_min = _mm256_min_pd(current_min, work);
         current_max = _mm256_max_pd(current_max, work);
         buf += 4;
@@ -97,8 +95,8 @@ void avx_minmax_val(const double *restrict buf, long nframes, double *min, doubl
     }
 
     /* work through the remainung values */
-    while ( nframes > 0) {
-        work = _mm256_set1_pd(*buf);
+    while (nframes > 0) {
+        work        = _mm256_set1_pd(*buf);
         current_min = _mm256_min_pd(current_min, work);
         current_max = _mm256_max_pd(current_max, work);
         buf++;
@@ -107,19 +105,19 @@ void avx_minmax_val(const double *restrict buf, long nframes, double *min, doubl
 
     /* find min & max value through shuffle tricks */
 
-    work = current_min;
-    work = _mm256_shuffle_pd(work, work, _MM_SHUFFLE(2, 3, 0, 1));
-    work = _mm256_min_pd (work, current_min);
+    work        = current_min;
+    work        = _mm256_shuffle_pd(work, work, _MM_SHUFFLE(2, 3, 0, 1));
+    work        = _mm256_min_pd(work, current_min);
     current_min = work;
-    work = _mm256_shuffle_pd(work, work, _MM_SHUFFLE(1, 0, 3, 2));
-    work = _mm256_min_pd (work, current_min);
+    work        = _mm256_shuffle_pd(work, work, _MM_SHUFFLE(1, 0, 3, 2));
+    work        = _mm256_min_pd(work, current_min);
     _mm256_store_pd(min, work);
-    work = current_max;
-    work = _mm256_shuffle_pd(work, work, _MM_SHUFFLE(2, 3, 0, 1));
-    work = _mm256_max_pd (work, current_max);
+    work        = current_max;
+    work        = _mm256_shuffle_pd(work, work, _MM_SHUFFLE(2, 3, 0, 1));
+    work        = _mm256_max_pd(work, current_max);
     current_max = work;
-    work = _mm256_shuffle_pd(work, work, _MM_SHUFFLE(1, 0, 3, 2));
-    work = _mm256_max_pd (work, current_max);
+    work        = _mm256_shuffle_pd(work, work, _MM_SHUFFLE(1, 0, 3, 2));
+    work        = _mm256_max_pd(work, current_max);
     _mm256_store_pd(max, work);
 
     return;
@@ -128,8 +126,7 @@ void avx_minmax_val(const double *restrict buf, long nframes, double *min, doubl
 #else
 
 #ifdef __SSE2__
-static
-void sse2_minmax_val(const double *restrict buf, long nframes, double *min, double *max)
+static void sse2_minmax_val(const double* restrict buf, long nframes, double* min, double* max)
 {
     __m128d current_max, current_min, work;
 
@@ -138,10 +135,9 @@ void sse2_minmax_val(const double *restrict buf, long nframes, double *min, doub
     current_max = _mm_set1_pd(*max);
 
     /* work on input until buf reaches 16 byte alignment */
-    while ( ((unsigned long)buf) % 16 != 0 && nframes > 0) {
-
+    while (((unsigned long)buf) % 16 != 0 && nframes > 0) {
         /* load one double and replicate */
-        work = _mm_set1_pd(*buf);
+        work        = _mm_set1_pd(*buf);
         current_min = _mm_min_pd(current_min, work);
         current_max = _mm_max_pd(current_max, work);
         buf++;
@@ -150,21 +146,21 @@ void sse2_minmax_val(const double *restrict buf, long nframes, double *min, doub
 
     while (nframes >= 8) {
         /* use 64 byte prefetch for double octetts */
-        __builtin_prefetch(buf+64,0,0); /* for GCC 4.3.2 + */
+        __builtin_prefetch(buf + 64, 0, 0); /* for GCC 4.3.2 + */
 
-        work = _mm_load_pd(buf);
+        work        = _mm_load_pd(buf);
         current_min = _mm_min_pd(current_min, work);
         current_max = _mm_max_pd(current_max, work);
         buf += 2;
-        work = _mm_load_pd(buf);
+        work        = _mm_load_pd(buf);
         current_min = _mm_min_pd(current_min, work);
         current_max = _mm_max_pd(current_max, work);
         buf += 2;
-        work = _mm_load_pd(buf);
+        work        = _mm_load_pd(buf);
         current_min = _mm_min_pd(current_min, work);
         current_max = _mm_max_pd(current_max, work);
         buf += 2;
-        work = _mm_load_pd(buf);
+        work        = _mm_load_pd(buf);
         current_min = _mm_min_pd(current_min, work);
         current_max = _mm_max_pd(current_max, work);
         buf += 2;
@@ -173,7 +169,7 @@ void sse2_minmax_val(const double *restrict buf, long nframes, double *min, doub
 
     /* work through smaller chunks of aligned buffers without prefetching */
     while (nframes >= 2) {
-        work = _mm_load_pd(buf);
+        work        = _mm_load_pd(buf);
         current_min = _mm_min_pd(current_min, work);
         current_max = _mm_max_pd(current_max, work);
         buf += 2;
@@ -181,9 +177,9 @@ void sse2_minmax_val(const double *restrict buf, long nframes, double *min, doub
     }
 
     /* work through the remaining value */
-    while ( nframes > 0) {
+    while (nframes > 0) {
         /* load the last double and replicate */
-        work = _mm_set1_pd(*buf);
+        work        = _mm_set1_pd(*buf);
         current_min = _mm_min_pd(current_min, work);
         current_max = _mm_max_pd(current_max, work);
         buf++;
@@ -193,11 +189,11 @@ void sse2_minmax_val(const double *restrict buf, long nframes, double *min, doub
     /* find final min and max value through shuffle tricks */
     work = current_min;
     work = _mm_shuffle_pd(work, work, _MM_SHUFFLE2(0, 1));
-    work = _mm_min_pd (work, current_min);
+    work = _mm_min_pd(work, current_min);
     _mm_store_sd(min, work);
     work = current_max;
     work = _mm_shuffle_pd(work, work, _MM_SHUFFLE2(0, 1));
-    work = _mm_max_pd (work, current_max);
+    work = _mm_max_pd(work, current_max);
     _mm_store_sd(max, work);
 
     return;
@@ -206,16 +202,16 @@ void sse2_minmax_val(const double *restrict buf, long nframes, double *min, doub
 
 #endif
 
-static
-void minmax_val(const double *restrict data, long datasize, double *fmin, double *fmax)
+static void minmax_val(const double* restrict data, long datasize, double* fmin, double* fmax)
 {
-#ifdef _GET_X86_COUNTER 
+#ifdef _GET_X86_COUNTER
     uint64_t start_minmax, end_minmax;
 #endif
 
-    if ( datasize < 1 ) return;
+    if (datasize < 1)
+        return;
 
-#ifdef _GET_X86_COUNTER 
+#ifdef _GET_X86_COUNTER
     start_minmax = _rdtsc();
 #endif
 
@@ -235,76 +231,72 @@ void minmax_val(const double *restrict data, long datasize, double *fmin, double
 #ifdef _ARCH_PWR6
 #define __UNROLL_DEPTH_1 6
 
-    /* to allow pipelining we have to unroll */
+        /* to allow pipelining we have to unroll */
 
-#ifdef _GET_IBM_COUNTER 
+#ifdef _GET_IBM_COUNTER
     hpmStart(1, "minmax fsel");
 #endif
     {
         long i, j;
-        long residual =  datasize % __UNROLL_DEPTH_1;
+        long residual = datasize % __UNROLL_DEPTH_1;
         long ofs = datasize - residual;
         double register dmin[__UNROLL_DEPTH_1];
         double register dmax[__UNROLL_DEPTH_1];
 
-        for ( j = 0; j < __UNROLL_DEPTH_1; j++)
-        {
+        for (j = 0; j < __UNROLL_DEPTH_1; j++) {
             dmin[j] = data[0];
             dmax[j] = data[0];
         }
 
-        for ( i = 0; i < datasize - residual; i += __UNROLL_DEPTH_1 )
-        {
-            for (j = 0; j < __UNROLL_DEPTH_1; j++)
-            {
-                dmin[j] = __fsel(dmin[j] - data[i+j], data[i+j], dmin[j]);
-                dmax[j] = __fsel(data[i+j] - dmax[j], data[i+j], dmax[j]);
+        for (i = 0; i < datasize - residual; i += __UNROLL_DEPTH_1) {
+            for (j = 0; j < __UNROLL_DEPTH_1; j++) {
+                dmin[j] = __fsel(dmin[j] - data[i + j], data[i + j], dmin[j]);
+                dmax[j] = __fsel(data[i + j] - dmax[j], data[i + j], dmax[j]);
             }
         }
 
-        for (j = 0; j < residual; j++)
-        {
-            dmin[j] = __fsel(dmin[j] - data[ofs+j], data[ofs+j], dmin[j]);
-            dmax[j] = __fsel(data[ofs+j] - dmax[j], data[ofs+j], dmax[j]);
+        for (j = 0; j < residual; j++) {
+            dmin[j] = __fsel(dmin[j] - data[ofs + j], data[ofs + j], dmin[j]);
+            dmax[j] = __fsel(data[ofs + j] - dmax[j], data[ofs + j], dmax[j]);
         }
 
-        for ( j = 0; j < __UNROLL_DEPTH_1; j++)
-        {
+        for (j = 0; j < __UNROLL_DEPTH_1; j++) {
             *fmin = __fsel(*fmin - dmin[j], dmin[j], *fmin);
             *fmax = __fsel(dmax[j] - *fmax, dmax[j], *fmax);
         }
     }
-#ifdef _GET_IBM_COUNTER 
+#ifdef _GET_IBM_COUNTER
     hpmStop(1);
 #endif
 
 #undef __UNROLL_DEPTH_1
 #else
 
-#ifdef _GET_IBM_COUNTER 
+#ifdef _GET_IBM_COUNTER
     hpmStart(1, "minmax base");
 #endif
     {
         long i;
 
-#if   defined (CRAY)
+#if defined(CRAY)
 #pragma _CRI ivdep
-#elif defined (SX)
+#elif defined(SX)
 #pragma vdir nodep
-#elif defined (__uxp__)
+#elif defined(__uxp__)
 #pragma loop novrec
 #endif
-        for ( i = 0; i < datasize; ++i )
-        {
-            if ( *fmin > data[i] ) *fmin = data[i];
-            if ( *fmax < data[i] ) *fmax = data[i];
+        for (i = 0; i < datasize; ++i) {
+            if (*fmin > data[i])
+                *fmin = data[i];
+            if (*fmax < data[i])
+                *fmax = data[i];
             /*
              *fmin = *fmin < data[i] ? *fmin : data[i];
              *fmax = *fmax > data[i] ? *fmax : data[i];
              */
         }
     }
-#ifdef _GET_IBM_COUNTER 
+#ifdef _GET_IBM_COUNTER
     hpmStop(1);
 #endif
 
@@ -312,19 +304,19 @@ void minmax_val(const double *restrict data, long datasize, double *fmin, double
 #endif
 #endif
 
-#ifdef _GET_X86_COUNTER 
+#ifdef _GET_X86_COUNTER
     end_minmax = _rdtsc();
 #ifdef __AVX__
     printf("AVX cycles:: %" PRIu64 "\n",
-            end_minmax-start_minmax);
+           end_minmax - start_minmax);
 #else
 #ifdef __SSE2__
     printf("SSE2 cycles:: %" PRIu64 "\n",
-            end_minmax-start_minmax);
+           end_minmax - start_minmax);
 #else
     printf("loop cycles:: %" PRIu64 "\n",
-            end_minmax-start_minmax);
-#endif  
+           end_minmax - start_minmax);
+#endif
 #endif
 #endif
 
