@@ -1,5 +1,5 @@
 #!/bin/sh
-# Copyright 2005-2019 ECMWF.
+# (C) Copyright 2005- ECMWF.
 #
 # This software is licensed under the terms of the Apache Licence Version 2.0
 # which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -23,6 +23,13 @@ JSON_CHECK=""
 if command -v $JSON_VERIF >/dev/null 2>&1; then
   JSON_CHECK=$JSON_VERIF
 fi
+# ECC-1119: Check the json_xs command actually works!
+set +e
+echo '[]' | json_xs > /dev/null 2>&1
+if [ $? -ne 0 ]; then JSON_CHECK=""; fi
+set -e
+echo "Using $JSON_CHECK ..."
+
 
 bufr_files=`cat bufr_data_files.txt`
 for file in ${bufr_files}
