@@ -21,9 +21,9 @@ files="reduced_latlon_surface.grib1 \
       reduced_gaussian_sub_area.grib2 \
       regular_latlon_surface.grib2"
 
-for f in `echo $files`
-do
+for f in $files; do
  file=${data_dir}/$f
+ # Must exclude the first line of grib_get_data which is "Latitude, Longitude, Value"
  iterator_count=`${tools_dir}/grib_get_data -m 9999:missing -f -p centre -F "%g" -w count=1 $file | grep -v Lat |wc -l `
  numberOfPoints=`${tools_dir}/grib_get -w count=1 -p numberOfPoints $file`
  [ $numberOfPoints = ${iterator_count} ]
