@@ -835,133 +835,130 @@ static double values[] = {
 };
 
 
-int main (int argc, char *argv[])
+int main(int argc, char* argv[])
 {
-    grib_handle *h;
+    grib_handle* h;
     size_t len;
-    const char *grids[] = { "lambert_lam", "mercator_lam", "polar_stereographic_lam" };
+    const char* grids[] = { "lambert_lam", "mercator_lam", "polar_stereographic_lam" };
     int igrid;
 
-    for (igrid = 0; igrid < 3; igrid++)
-    {
-        GRIB_CHECK (((h = grib_handle_new_from_samples (NULL, "regular_ll_pl_grib2")) == NULL), 0);
-        len = strlen ("lambert_lam");
-        GRIB_CHECK (grib_set_string (h, "gridType", "lambert_lam", &len), 0);
-        GRIB_CHECK (grib_set_long (h, "centre", 85), 0);
-        len = strlen (grids[igrid]);
-        GRIB_CHECK (grib_set_string (h, "gridType", grids[igrid], &len), 0);
-        GRIB_CHECK (grib_set_long (h, "Nx", 64), 0);
-        GRIB_CHECK (grib_set_long (h, "Ny", 64), 0);
-        GRIB_CHECK (grib_set_long (h, "iScansNegatively", 0), 0);
-        GRIB_CHECK (grib_set_long (h, "jScansPositively", 1), 0);
-        GRIB_CHECK (grib_set_long (h, "jPointsAreConsecutive", 0), 0);
-        GRIB_CHECK (grib_set_long (h, "Nux", 53), 0);
-        GRIB_CHECK (grib_set_long (h, "Nuy", 53), 0);
-        GRIB_CHECK (grib_set_long (h, "Ncx", 8), 0);
-        GRIB_CHECK (grib_set_long (h, "Ncy", 8), 0);
+    for (igrid = 0; igrid < 3; igrid++) {
+        GRIB_CHECK(((h = grib_handle_new_from_samples(NULL, "regular_ll_pl_grib2")) == NULL), 0);
+        len = strlen("lambert_lam");
+        GRIB_CHECK(grib_set_string(h, "gridType", "lambert_lam", &len), 0);
+        GRIB_CHECK(grib_set_long(h, "centre", 85), 0);
+        len = strlen(grids[igrid]);
+        GRIB_CHECK(grib_set_string(h, "gridType", grids[igrid], &len), 0);
+        GRIB_CHECK(grib_set_long(h, "Nx", 64), 0);
+        GRIB_CHECK(grib_set_long(h, "Ny", 64), 0);
+        GRIB_CHECK(grib_set_long(h, "iScansNegatively", 0), 0);
+        GRIB_CHECK(grib_set_long(h, "jScansPositively", 1), 0);
+        GRIB_CHECK(grib_set_long(h, "jPointsAreConsecutive", 0), 0);
+        GRIB_CHECK(grib_set_long(h, "Nux", 53), 0);
+        GRIB_CHECK(grib_set_long(h, "Nuy", 53), 0);
+        GRIB_CHECK(grib_set_long(h, "Ncx", 8), 0);
+        GRIB_CHECK(grib_set_long(h, "Ncy", 8), 0);
 
         if (igrid == 0) {
-            GRIB_CHECK (grib_set_double (h, "DxInMetres", 2500.00000000000), 0);
-            GRIB_CHECK (grib_set_double (h, "DyInMetres", 2500.00000000000), 0);
-            GRIB_CHECK (grib_set_double (h, "latitudeOfFirstGridPointInDegrees", 66.7684949529709), 0);
-            GRIB_CHECK (grib_set_double (h, "longitudeOfFirstGridPointInDegrees", 25.1580207144963), 0);
-            GRIB_CHECK (grib_set_double (h, "latitudeOfSouthernPoleInDegrees", 0.000000000000000E+000), 0);
-            GRIB_CHECK (grib_set_double (h, "longitudeOfSouthernPoleInDegrees", 0.000000000000000E+000), 0);
-            GRIB_CHECK (grib_set_double (h, "LaDInDegrees", 67.3600000000000), 0);
-            GRIB_CHECK (grib_set_double (h, "LoVInDegrees", 26.6400000000000), 0);
-            GRIB_CHECK (grib_set_double (h, "Latin1InDegrees", 67.3600000000000), 0);
-            GRIB_CHECK (grib_set_double (h, "Latin2InDegrees", 67.3600000000000), 0);
-            GRIB_CHECK (grib_set_long (h, "projectionCentreFlag", 0), 0);
-            GRIB_CHECK (grib_set_long (h, "uvRelativeToGrid", 1), 0);
+            GRIB_CHECK(grib_set_double(h, "DxInMetres", 2500.00000000000), 0);
+            GRIB_CHECK(grib_set_double(h, "DyInMetres", 2500.00000000000), 0);
+            GRIB_CHECK(grib_set_double(h, "latitudeOfFirstGridPointInDegrees", 66.7684949529709), 0);
+            GRIB_CHECK(grib_set_double(h, "longitudeOfFirstGridPointInDegrees", 25.1580207144963), 0);
+            GRIB_CHECK(grib_set_double(h, "latitudeOfSouthernPoleInDegrees", 0.000000000000000E+000), 0);
+            GRIB_CHECK(grib_set_double(h, "longitudeOfSouthernPoleInDegrees", 0.000000000000000E+000), 0);
+            GRIB_CHECK(grib_set_double(h, "LaDInDegrees", 67.3600000000000), 0);
+            GRIB_CHECK(grib_set_double(h, "LoVInDegrees", 26.6400000000000), 0);
+            GRIB_CHECK(grib_set_double(h, "Latin1InDegrees", 67.3600000000000), 0);
+            GRIB_CHECK(grib_set_double(h, "Latin2InDegrees", 67.3600000000000), 0);
+            GRIB_CHECK(grib_set_long(h, "projectionCentreFlag", 0), 0);
+            GRIB_CHECK(grib_set_long(h, "uvRelativeToGrid", 1), 0);
         }
         else if (igrid == 1) {
-            GRIB_CHECK (grib_set_double (h, "latitudeOfFirstGridPointInDegrees", 67.9372009520603), 0);
-            GRIB_CHECK (grib_set_double (h, "longitudeOfFirstGridPointInDegrees", 25.1580207144963), 0);
-            GRIB_CHECK (grib_set_double (h, "LaDInDegrees", 0.), 0);
-            GRIB_CHECK (grib_set_double (h, "latitudeOfLastGridPointInDegrees", 72.9372009520603), 0);
-            GRIB_CHECK (grib_set_double (h, "longitudeOfLastGridPointInDegrees", 29.1580207144963), 0);
-            GRIB_CHECK (grib_set_double (h, "orientationOfTheGridInDegrees", 0.), 0);
-            GRIB_CHECK (grib_set_long (h, "uvRelativeToGrid", 1), 0);
+            GRIB_CHECK(grib_set_double(h, "latitudeOfFirstGridPointInDegrees", 67.9372009520603), 0);
+            GRIB_CHECK(grib_set_double(h, "longitudeOfFirstGridPointInDegrees", 25.1580207144963), 0);
+            GRIB_CHECK(grib_set_double(h, "LaDInDegrees", 0.), 0);
+            GRIB_CHECK(grib_set_double(h, "latitudeOfLastGridPointInDegrees", 72.9372009520603), 0);
+            GRIB_CHECK(grib_set_double(h, "longitudeOfLastGridPointInDegrees", 29.1580207144963), 0);
+            GRIB_CHECK(grib_set_double(h, "orientationOfTheGridInDegrees", 0.), 0);
+            GRIB_CHECK(grib_set_long(h, "uvRelativeToGrid", 1), 0);
         }
         else if (igrid == 2) {
-            GRIB_CHECK (grib_set_double (h, "DxInMetres", 2500.00000000000), 0);
-            GRIB_CHECK (grib_set_double (h, "DyInMetres", 2500.00000000000), 0);
-            GRIB_CHECK (grib_set_double (h, "latitudeOfFirstGridPointInDegrees", 67.9372009520603), 0);
-            GRIB_CHECK (grib_set_double (h, "longitudeOfFirstGridPointInDegrees", 25.1580207144963), 0);
-            GRIB_CHECK (grib_set_double (h, "LaDInDegrees", 0.), 0);
-            GRIB_CHECK (grib_set_double (h, "orientationOfTheGridInDegrees", 0.), 0);
+            GRIB_CHECK(grib_set_double(h, "DxInMetres", 2500.00000000000), 0);
+            GRIB_CHECK(grib_set_double(h, "DyInMetres", 2500.00000000000), 0);
+            GRIB_CHECK(grib_set_double(h, "latitudeOfFirstGridPointInDegrees", 67.9372009520603), 0);
+            GRIB_CHECK(grib_set_double(h, "longitudeOfFirstGridPointInDegrees", 25.1580207144963), 0);
+            GRIB_CHECK(grib_set_double(h, "LaDInDegrees", 0.), 0);
+            GRIB_CHECK(grib_set_double(h, "orientationOfTheGridInDegrees", 0.), 0);
         }
 
-        GRIB_CHECK (grib_set_long (h, "NV", 0), 0);
-        GRIB_CHECK (grib_set_long (h, "year", 2009), 0);
-        GRIB_CHECK (grib_set_long (h, "month", 5), 0);
-        GRIB_CHECK (grib_set_long (h, "day", 28), 0);
-        GRIB_CHECK (grib_set_long (h, "hour", 0), 0);
-        GRIB_CHECK (grib_set_long (h, "minute", 0), 0);
-        GRIB_CHECK (grib_set_long (h, "second", 0), 0);
-        len = strlen ("s");
-        GRIB_CHECK (grib_set_string (h, "indicatorOfUnitOfTimeRange", "s", &len), 0);
-        len = strlen ("s");
-        GRIB_CHECK (grib_set_string (h, "stepUnits", "s", &len), 0);
-        GRIB_CHECK (grib_set_long (h, "endStep", 3600), 0);
-        GRIB_CHECK (grib_set_long (h, "bitsPerValue", 16), 0);
-        len = strlen ("grid_simple");
-        GRIB_CHECK (grib_set_string (h, "packingType", "grid_simple", &len), 0);
-        GRIB_CHECK (grib_set_long (h, "numberOfDataPoints", 4096), 0);
+        GRIB_CHECK(grib_set_long(h, "NV", 0), 0);
+        GRIB_CHECK(grib_set_long(h, "year", 2009), 0);
+        GRIB_CHECK(grib_set_long(h, "month", 5), 0);
+        GRIB_CHECK(grib_set_long(h, "day", 28), 0);
+        GRIB_CHECK(grib_set_long(h, "hour", 0), 0);
+        GRIB_CHECK(grib_set_long(h, "minute", 0), 0);
+        GRIB_CHECK(grib_set_long(h, "second", 0), 0);
+        len = strlen("s");
+        GRIB_CHECK(grib_set_string(h, "indicatorOfUnitOfTimeRange", "s", &len), 0);
+        len = strlen("s");
+        GRIB_CHECK(grib_set_string(h, "stepUnits", "s", &len), 0);
+        GRIB_CHECK(grib_set_long(h, "endStep", 3600), 0);
+        GRIB_CHECK(grib_set_long(h, "bitsPerValue", 16), 0);
+        len = strlen("grid_simple");
+        GRIB_CHECK(grib_set_string(h, "packingType", "grid_simple", &len), 0);
+        GRIB_CHECK(grib_set_long(h, "numberOfDataPoints", 4096), 0);
         len = 4096;
-        GRIB_CHECK (grib_set_double_array (h, "values", values, len), 0);
+        GRIB_CHECK(grib_set_double_array(h, "values", values, len), 0);
 
         if (1) {
             char f[128];
-            FILE *fp;
+            FILE* fp;
             size_t size;
-            const void *buffer = NULL;
-            sprintf (f, "lam_gp_%s.grib", grids[igrid]);
-            fp = fopen (f, "wb");
-            GRIB_CHECK (grib_get_message (h, &buffer, &size), 0);
-            if (fwrite (buffer, 1, size, fp) != size)
-            {
-                perror (f);
+            const void* buffer = NULL;
+            sprintf(f, "lam_gp_%s.grib", grids[igrid]);
+            fp = fopen(f, "wb");
+            GRIB_CHECK(grib_get_message(h, &buffer, &size), 0);
+            if (fwrite(buffer, 1, size, fp) != size) {
+                perror(f);
                 return 1;
             }
-            fclose (fp);
+            fclose(fp);
         }
 
-        GRIB_CHECK (grib_handle_delete (h), 0);
+        GRIB_CHECK(grib_handle_delete(h), 0);
 
         /* Check message correctness */
         {
             char f[128];
-            FILE *fp;
-            double *vals;
+            FILE* fp;
+            double* vals;
             double norm = 0.;
             int i, err;
             size_t values_len, geometry_len;
             long int Nux, Nuy, Ncx, Ncy;
             char geometry[128];
 
-            sprintf (f, "lam_gp_%s.grib", grids[igrid]);
-            fp = fopen (f, "rb");
-            h = grib_handle_new_from_file (0, fp, &err);
-            vals = (double *) malloc (sizeof (double) * 4096);
+            sprintf(f, "lam_gp_%s.grib", grids[igrid]);
+            fp         = fopen(f, "rb");
+            h          = grib_handle_new_from_file(0, fp, &err);
+            vals       = (double*)malloc(sizeof(double) * 4096);
             values_len = 4096;
-            GRIB_CHECK (grib_get_double_array (h, "values", vals, &values_len), 0);
+            GRIB_CHECK(grib_get_double_array(h, "values", vals, &values_len), 0);
             for (i = 0; i < 4096; i++)
                 norm += (values[i] - vals[i]) * (values[i] - vals[i]);
-            norm = sqrt (norm / 4096);
-            free (vals);
-            printf ("%s : %lf\n", grids[igrid], norm);
-            if (norm > 0.0001)
-            {
+            norm = sqrt(norm / 4096);
+            free(vals);
+            printf("%s : %lf\n", grids[igrid], norm);
+            if (norm > 0.0001) {
                 fprintf(stderr, "Error too large !\n");
                 return 1;
             }
-            fclose (fp);
+            fclose(fp);
 
-            GRIB_CHECK (grib_get_long (h, "Nux", &Nux), 0);
-            GRIB_CHECK (grib_get_long (h, "Nuy", &Nuy), 0);
-            GRIB_CHECK (grib_get_long (h, "Ncx", &Ncx), 0);
-            GRIB_CHECK (grib_get_long (h, "Ncy", &Ncy), 0);
+            GRIB_CHECK(grib_get_long(h, "Nux", &Nux), 0);
+            GRIB_CHECK(grib_get_long(h, "Nuy", &Nuy), 0);
+            GRIB_CHECK(grib_get_long(h, "Ncx", &Ncx), 0);
+            GRIB_CHECK(grib_get_long(h, "Ncy", &Ncy), 0);
 
             if (Nux != 53 || Nuy != 53 || Ncx != 8 || Ncy != 8) {
                 fprintf(stderr, "Geometry is incorrect\n");
@@ -969,13 +966,13 @@ int main (int argc, char *argv[])
             }
 
             geometry_len = 128;
-            GRIB_CHECK (grib_get_string (h, "gridType", geometry, &geometry_len), 0);
-            if (strcmp (geometry, grids[igrid])) {
+            GRIB_CHECK(grib_get_string(h, "gridType", geometry, &geometry_len), 0);
+            if (strcmp(geometry, grids[igrid])) {
                 fprintf(stderr, "Geometry is incorrect\n");
                 return 1;
             }
 
-            GRIB_CHECK (grib_handle_delete (h), 0);
+            GRIB_CHECK(grib_handle_delete(h), 0);
         }
     }
     return 0;
