@@ -1,5 +1,5 @@
 #!/bin/sh
-# Copyright 2005-2019 ECMWF.
+# (C) Copyright 2005- ECMWF.
 #
 # This software is licensed under the terms of the Apache Licence Version 2.0
 # which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -58,9 +58,20 @@ if [ $HAVE_JPEG -eq 1 ]; then
     [ "$res" = "2 1 grid_jpeg" ]
 fi
 
+# Convert to edition2 and use CCSDS for packing
+if [ $HAVE_AEC -eq 1 ]; then
+    infile=../data/latlon.grib
+    $EXEC $grib_util_set_spec -e 2 -p grid_ccsds $infile $outfile > /dev/null
+    res=`${tools_dir}/grib_get -p edition,section2Used,packingType $outfile`
+    [ "$res" = "2 1 grid_ccsds" ]
+fi
+
 # --------------------------------------------------
 # Reduced Gaussian Grid N=32 second order packing
 # --------------------------------------------------
+# The gaussian tests intentionally cause an error so need to stop it failing
+unset ECCODES_FAIL_IF_LOG_MESSAGE
+
 infile=../data/reduced_gaussian_model_level.grib2
 outfile=out.grib_util_set_spec.grib
 rm -f $outfile
@@ -93,3 +104,4 @@ ${tools_dir}/grib_get_data $outfile > /dev/null
 
 ### Clean up
 rm -f $outfile $tempOut
+rm -f error.data
