@@ -54,7 +54,7 @@ static grib_error* error_summary;
 static compare_double_proc compare_double;
 static double global_tolerance     = 0;
 static int packingCompare          = 0;
-static grib_string_list* blacklist = 0;
+static grib_string_list* blocklist = 0;
 static int compareAbsolute         = 1;
 
 static int compare_handles(grib_handle* h1, grib_handle* h2, grib_runtime_options* options);
@@ -108,9 +108,9 @@ static double compare_double_relative(double* a, double* b, double tolerance)
     return relativeError > tolerance ? relativeError : 0;
 }
 
-static int blacklisted(const char* name)
+static int blocklisted(const char* name)
 {
-    grib_string_list* b = blacklist;
+    grib_string_list* b = blocklist;
     while (b) {
         Assert(b->value);
         if (!strcmp(name, b->value))
@@ -165,14 +165,14 @@ static int global_counter         = 0;
 static int theStart               = -1;
 static int theEnd                 = -1;
 
-const char* grib_tool_description =
+const char* tool_description =
     "Compare GRIB messages contained in two files."
     "\n\tIf some differences are found it fails returning an error code."
-    "\n\tFloating-point values are compared exactly by default, different tolerance can be defined see -P -A -R."
+    "\n\tFloating-point values are compared exactly by default, different tolerances can be defined (see -P -A -R)."
     "\n\tDefault behaviour: absolute error=0, bit-by-bit compare, same order in files.";
 
-const char* grib_tool_name  = "grib_compare";
-const char* grib_tool_usage = "[options] grib_file1 grib_file2";
+const char* tool_name  = "grib_compare";
+const char* tool_usage = "[options] grib_file1 grib_file2";
 
 int grib_options_count = sizeof(grib_options) / sizeof(grib_option);
 
@@ -237,15 +237,15 @@ int grib_tool_init(grib_runtime_options* options)
 
     if (grib_options_on("b:")) {
         grib_string_list* next = 0;
-        blacklist              = (grib_string_list*)grib_context_malloc_clear(context, sizeof(grib_string_list));
-        blacklist->value       = grib_context_strdup(context, options->set_values[0].name);
-        next                   = blacklist;
+        blocklist              = (grib_string_list*)grib_context_malloc_clear(context, sizeof(grib_string_list));
+        blocklist->value       = grib_context_strdup(context, options->set_values[0].name);
+        next                   = blocklist;
         for (i = 1; i < options->set_values_count; i++) {
             next->next        = (grib_string_list*)grib_context_malloc_clear(context, sizeof(grib_string_list));
             next->next->value = grib_context_strdup(context, options->set_values[i].name);
             next              = next->next;
         }
-        context->blacklist = blacklist;
+        context->blocklist = blocklist;
     }
 
     if (grib_options_on("r")) {
@@ -319,7 +319,7 @@ int grib_tool_init(grib_runtime_options* options)
     if (grib_options_on("R:")) {
         char* sarg               = grib_options_get_option("R:");
         options->tolerance_count = MAX_KEYS;
-        ret                      = parse_keyval_string(grib_tool_name, sarg, 1, GRIB_TYPE_DOUBLE, options->tolerance, &(options->tolerance_count));
+        ret                      = parse_keyval_string(tool_name, sarg, 1, GRIB_TYPE_DOUBLE, options->tolerance, &(options->tolerance_count));
         if (ret == GRIB_INVALID_ARGUMENT) {
             usage();
             exit(1);
@@ -653,8 +653,8 @@ static int compare_values(grib_runtime_options* options, grib_handle* h1, grib_h
     if (verbose)
         printf("  comparing %s", name);
 
-    /* If key was blacklisted, then we should not have got here */
-    DebugAssert(!blacklisted(name));
+    /* If key was blocklisted, then we should not have got here */
+    DebugAssert(!blocklisted(name));
 
     if (type1 == GRIB_TYPE_UNDEFINED && (err = grib_get_native_type(h1, name, &type1)) != GRIB_SUCCESS) {
         printInfo(h1);
@@ -1130,9 +1130,9 @@ static int compare_handles(grib_handle* h1, grib_handle* h2, grib_runtime_option
     grib_keys_iterator* iter = NULL;
 
     /* mask only if no -c option or headerMode (-H)*/
-    if (blacklist && (!listFromCommandLine || headerMode)) {
+    if (blocklist && (!listFromCommandLine || headerMode)) {
         /* See ECC-245, GRIB-573, GRIB-915: Do not change handles in memory */
-        /* grib_string_list* nextb=blacklist;
+        /* grib_string_list* nextb=blocklist;
         while (nextb) {
             grib_clear(h1,nextb->value);
             grib_clear(h2,nextb->value);
@@ -1164,7 +1164,7 @@ static int compare_handles(grib_handle* h1, grib_handle* h2, grib_runtime_option
             name = grib_keys_iterator_get_name(iter);
             /*printf("----- comparing %s\n",name);*/
 
-            if (blacklisted(name))
+            if (blocklisted(name))
                 continue;
             if (compare_values(options, h11, h22, name, GRIB_TYPE_UNDEFINED))
                 err++;
@@ -1178,7 +1178,7 @@ static int compare_handles(grib_handle* h1, grib_handle* h2, grib_runtime_option
 
     if (listFromCommandLine && onlyListed) {
         for (i = 0; i < options->compare_count; i++) {
-            if (blacklisted(options->compare[i].name))
+            if (blocklisted(options->compare[i].name))
                 continue;
             if (options->compare[i].type == GRIB_NAMESPACE) {
                 iter = grib_keys_iterator_new(h1, 0, options->compare[i].name);
@@ -1190,7 +1190,7 @@ static int compare_handles(grib_handle* h1, grib_handle* h2, grib_runtime_option
                     name = grib_keys_iterator_get_name(iter);
                     /*printf("----- comparing %s\n",name);*/
 
-                    if (blacklisted(name))
+                    if (blocklisted(name))
                         continue;
                     if (compare_values(options, h1, h2, name, GRIB_TYPE_UNDEFINED))
                         err++;
@@ -1222,7 +1222,7 @@ static int compare_handles(grib_handle* h1, grib_handle* h2, grib_runtime_option
             name = grib_keys_iterator_get_name(iter);
             /*printf("----- comparing %s\n",name);*/
 
-            if (blacklisted(name))
+            if (blocklisted(name))
                 continue;
             if (compare_values(options, h1, h2, name, GRIB_TYPE_UNDEFINED))
                 err++;
@@ -1232,7 +1232,7 @@ static int compare_handles(grib_handle* h1, grib_handle* h2, grib_runtime_option
 
         if (listFromCommandLine) {
             for (i = 0; i < options->compare_count; i++) {
-                if (blacklisted(options->compare[i].name))
+                if (blocklisted(options->compare[i].name))
                     continue;
                 if (options->compare[i].type == GRIB_NAMESPACE) {
                     iter = grib_keys_iterator_new(h1, 0, options->compare[i].name);
@@ -1244,7 +1244,7 @@ static int compare_handles(grib_handle* h1, grib_handle* h2, grib_runtime_option
                         name = grib_keys_iterator_get_name(iter);
                         /*printf("----- comparing %s\n",name);*/
 
-                        if (blacklisted(name))
+                        if (blocklisted(name))
                             continue;
                         if (compare_values(options, h1, h2, name, GRIB_TYPE_UNDEFINED))
                             err++;
