@@ -39,11 +39,11 @@ grib_option grib_options[] = {
     { "V", 0, 0, 0, 1, 0 }
 };
 
-const char* grib_tool_description =
+const char* tool_description =
     "Print a latitude, longitude, data values list.\n"
     "\tNote: Rotated grids are first unrotated";
-const char* grib_tool_name  = "grib_get_data";
-const char* grib_tool_usage = "[options] grib_file grib_file ...";
+const char* tool_name  = "grib_get_data";
+const char* tool_usage = "[options] grib_file grib_file ...";
 
 extern FILE* dump_file;
 
@@ -71,7 +71,7 @@ int grib_tool_new_filename_action(grib_runtime_options* options, const char* fil
 
 int grib_tool_new_file_action(grib_runtime_options* options, grib_tools_file* file)
 {
-    exit_if_input_is_directory(grib_tool_name, file->name);
+    exit_if_input_is_directory(tool_name, file->name);
     return 0;
 }
 
