@@ -19,9 +19,9 @@ grib_option grib_options[] = {
 };
 int grib_options_count = sizeof(grib_options) / sizeof(grib_option);
 
-const char* grib_tool_description = "Histogram of GRIB files";
-const char* grib_tool_name        = "grib_histogram";
-const char* grib_tool_usage       = "[options] grib_file grib_file ...";
+const char* tool_description = "Histogram of GRIB files";
+const char* tool_name        = "grib_histogram";
+const char* tool_usage       = "[options] grib_file grib_file ...";
 
 int main(int argc, char* argv[])
 {
@@ -45,7 +45,7 @@ int grib_tool_new_filename_action(grib_runtime_options* options, const char* fil
 
 int grib_tool_new_file_action(grib_runtime_options* options, grib_tools_file* file)
 {
-    exit_if_input_is_directory(grib_tool_name, file->name);
+    exit_if_input_is_directory(tool_name, file->name);
     return 0;
 }
 
