@@ -42,11 +42,11 @@ grib_option grib_options[] = {
     { "x", 0, 0, 0, 1, 0 }
 };
 
-const char* grib_tool_description =
+const char* tool_description =
     "List content of GRIB files printing values of "
     "some keys.\n\tIt does not fail when a key is not found.";
-const char* grib_tool_name  = "grib_ls";
-const char* grib_tool_usage = "[options] grib_file grib_file ...";
+const char* tool_name  = "grib_ls";
+const char* tool_usage = "[options] grib_file grib_file ...";
 static char* new_handle     = "";
 
 int grib_options_count = sizeof(grib_options) / sizeof(grib_option);
@@ -100,7 +100,7 @@ int grib_tool_init(grib_runtime_options* options)
     if (options->latlon) {
         lat = strtod(options->latlon, &theEnd);
         if (*theEnd != ',') {
-            fprintf(stderr, "Error %s: wrong latitude value. Please use 'latitude,longitude'\n",grib_tool_name);
+            fprintf(stderr, "Error %s: wrong latitude value. Please use 'latitude,longitude'\n",tool_name);
             exit(1);
         }
         lon = strtod(++theEnd, &end1);
@@ -120,7 +120,7 @@ int grib_tool_init(grib_runtime_options* options)
                     options->latlon_mode = 1;
                 }
                 else {
-                    fprintf(stderr, "Error %s: wrong mode given in option -l\n", grib_tool_name);
+                    fprintf(stderr, "Error %s: wrong mode given in option -l\n", tool_name);
                     exit(1);
                 }
             }
@@ -208,7 +208,7 @@ int grib_tool_new_filename_action(grib_runtime_options* options, const char* fil
 
 int grib_tool_new_file_action(grib_runtime_options* options, grib_tools_file* file)
 {
-    exit_if_input_is_directory(grib_tool_name, file->name);
+    exit_if_input_is_directory(tool_name, file->name);
     if (nearest)
         grib_nearest_delete(nearest);
     nearest = NULL;
