@@ -33,9 +33,9 @@ grib_option grib_options[] = {
     { "x", 0, 0, 0, 1, 0 }
 };
 
-const char* grib_tool_description = "Dump the content of a GTS file in different formats.";
-const char* grib_tool_name        = "gts_dump";
-const char* grib_tool_usage       = "[options] file file ...";
+const char* tool_description = "Dump the content of a GTS file in different formats.";
+const char* tool_name        = "gts_dump";
+const char* tool_usage       = "[options] file file ...";
 
 int grib_options_count = sizeof(grib_options) / sizeof(grib_option);
 
@@ -62,7 +62,7 @@ int grib_tool_init(grib_runtime_options* options)
 
 
     if (opt > 1) {
-        printf("%s: simultaneous O/D options not allowed\n", grib_tool_name);
+        printf("%s: simultaneous O/D options not allowed\n", tool_name);
         exit(1);
     }
 
